A module for visualizing streams
Enums
- Show
Feature Mode - The display mode for visualizing detected features
Functions
- download_
file - Convenience function for converting downloading a file at the given
video_url. Used for testing. - draw_
feature_ coord - Draw a cross on the given
imgat the givenxandycoordinates - draw_
feature_ event - Assuming the given event is a feature, draw it on the given
imgas a white cross - draw_
rect - Draw a rectangle on the given
imgwith the givencolor - encode_
video_ ffmpeg - Convenience function for converting binary grayscale data to an mp4. Used for testing.